==> djaodjin-signup-0.1.5.tar.gz: djaodjin-signup-0.1.5/signup/urls/users.py <==
# Copyright (c) 2014, Djaodjin Inc.
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice,
#    this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation
#    and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
# OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
# ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

from django.conf.urls import patterns, url

from signup.views import (PasswordChangeView, SendActivationView,
    UserProfileView, redirect_to_user_profile)

USERNAME_PAT = r'[\w.@+-]+'

urlpatterns = patterns('',
    # These three URLs must be protected.
    url(r'^(?P<user>%s)/activate/' % USERNAME_PAT,
        SendActivationView.as_view(), name='users_activate'),
    url(r'^(?P<user>%s)/password/' % USERNAME_PAT,
        PasswordChangeView.as_view(), name='password_change'),
    url(r'^(?P<user>%s)/' % USERNAME_PAT,
        UserProfileView.as_view(), name='users_profile'),
    url(r'^', redirect_to_user_profile, name='accounts_profile'),
)

==> djaodjin-signup-0.1.8.tar.gz: djaodjin-signup-0.1.8/signup/urls/users.py <==
# Copyright (c) 2016, Djaodjin Inc.
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice,
#    this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation
#    and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
# OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
# ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

from django.conf.urls import url

from signup.views import (PasswordChangeView, SendActivationView,
    UserProfileView, redirect_to_user_profile)

USERNAME_PAT = r'[\w.@+-]+'

urlpatterns = [
    # These three URLs must be protected.
    url(r'^(?P<user>%s)/activate/' % USERNAME_PAT,
        SendActivationView.as_view(), name='users_activate'),
    url(r'^(?P<user>%s)/password/' % USERNAME_PAT,
        PasswordChangeView.as_view(), name='password_change'),
    url(r'^(?P<user>%s)/' % USERNAME_PAT,
        UserProfileView.as_view(), name='users_profile'),
    url(r'^', redirect_to_user_profile, name='accounts_profile'),
]
